from . import __version__
from curvpyutils.version_utils import get_version_str as gvs

def get_version_str(short_version: bool = True) -> str:
    """Get the short package version string (major.minor.patch) or 
    long package version string (major.minor.patch.prerelease+build)."""
    return gvs(__version__, short_version)

__all__ = [
    "get_version_str",
]


from rich.console import Console
from rich.panel import Panel
from rich.text import Text
from curv import get_curv_version_str

import pytest
pytestmark = [pytest.mark.unit]

class TestCurvVersion:
    def test_get_version_str(self) -> None:
        console = Console()
        try:
            ver_short = get_curv_version_str(short_version=True)
            ver_full = get_curv_version_str(short_version=False)
            assert isinstance(ver_short, str)
            assert isinstance(ver_full, str)
            assert ver_short.split('.')[:3] == ver_full.split('.')[:3]
        except AssertionError as e:
            # Create a nicely formatted error message with rich
            error_text = Text()
            error_text.append("TestCurvVersion failed!\n\n", style="bold red")
            error_text.append(f"File: {e.__traceback__.tb_frame.f_code.co_filename}, line {e.__traceback__.tb_lineno}\n", style="cyan")
            error_text.append(f"Function: {e.__traceback__.tb_frame.f_code.co_name}\n\n", style="cyan")

            panel = Panel(error_text, title="[bold red]Assertion Error[/bold red]", border_style="red")
            console.print(panel)
            raise e

        # print success message
        success_text = Text("TestCurvVersion passed!", style="bold green")
        panel = Panel(success_text, title="[bold green]Success[/bold green]", border_style="green")
        console.print(panel)




try:
    from ._version import __version__
except Exception:
    try:
        from importlib.metadata import version as _v
        __version__ = _v("curv")
    except Exception:
        __version__ = "0.0.0.dev0+gunknown"
        
from .version import (
    get_version_str as get_curv_version_str,
)

__all__ = [
    "get_curv_version_str",
]


"""
Ensure local packages are importable when running pytest without editable installs.
"""
import sys
from pathlib import Path

repo_root = Path(__file__).resolve().parents[3]
src_paths = [
    repo_root / "packages" / "curvtools" / "src",
    repo_root / "packages" / "curvpyutils" / "src",
    repo_root / "packages" / "curv" / "src",
]
for p in src_paths:
    ps = str(p)
    if ps not in sys.path:
        sys.path.insert(0, ps)


